'use client'

import { useEffect, useRef, useState } from 'react'
import { CardGroup } from '@/components/ui/card-group'

import { Spinner } from '@/components/ui/spinner'
import {PlaneswalkerIcon, SorceryIcon, InstantIcon, CreatureIcon, EnchantmentIcon, LandIcon, ArtifactIcon} from '@/components/ui/symbols-icons'
import { MTGCard } from '@/components/ui/mtg-card'

interface PageContentProps {
  card_name:       string
}

interface commanderCardData {
  name: string,
  normal_image: string,
  nbr_decks: number,
  total_decks: number,
  price: string,
  cardmarket_uri: string,
}

export default function PageContent({card_name}: PageContentProps) {
  const [highSynergyList, setHighSynergyList] = useState([])
  const [creatureList, setCreatureList] = useState([])
  const [planeswalkerList, setPlaneswalkerList] = useState([])
  const [instantList, setInstantList] = useState([])
  const [sorceryList, setSorceryList] = useState([])
  const [artifactList, setArtifactList] = useState([])
  const [enchantmentList, setEnchantmentList] = useState([])
  const [landList, setLandList] = useState([])
  const [commanderCard, setCommanderCard] = useState<commanderCardData | null>(null)

  const [loading, setLoading] = useState(true)

  const [scrollState, setScrollState] = useState("commander")
  const CardListRef = useRef<HTMLDivElement>(null)

  useEffect(() => {
    fetch('/api/json/card-commander/'+card_name+'.json').then((res) => {
      if(res.status == 200) {
        res.json().then((data) => {
          setCommanderCard(data["card_data"])
          setHighSynergyList(data["high_synergy"])
          setCreatureList(data["creature"])
          setPlaneswalkerList(data["planeswalker"])
          setSorceryList(data["sorcery"])
          setInstantList(data["instant"])
          setEnchantmentList(data["enchantment"])
          setLandList(data["land"])
          setArtifactList(data["artifact"])
          setLoading(false)
          console.log(data)
        })
      }
    })
  }, []) 

  useEffect(() => {
    const handleScroll = () => {
      const windowHeight = window.innerHeight
      const TOP_MARGIN = 0.1
      const BOTTOM_MARGIN = 0.2
      const card_children = CardListRef.current?.children
      if (card_children) {
        for (const child of card_children){
          const targetBounds = child.getBoundingClientRect()
          if( targetBounds.bottom > windowHeight * TOP_MARGIN && targetBounds.top < windowHeight * ( 1 - BOTTOM_MARGIN ) ) {
            setScrollState(child.id)
            break
          }
        }
      }
    };

    // Add event listener to the window
    window.addEventListener('scroll', handleScroll);

    // Remove event listener when the component is unmounted
    return () => {
      window.removeEventListener('scroll', handleScroll);
    };
  }, []);
  return (
    <div>
      <div className="flex flex-col items-center w-full">
        <div className="flex flex-col items-center mt-24 mb-24 max-w-6xl">
          { loading && ( <Spinner className='mt-36' /> )}
          { !loading && (
            <div ref={CardListRef} className="flex flex-col items-center mt-24 gap-4 max-w-6xl">
              <div className="w-full flex flex-col items-center">
                <MTGCard className="w-64 h-auto" cardname={commanderCard!.name} imageURI={commanderCard!.normal_image} url={undefined} nbrDecks={commanderCard?.nbr_decks} totalDecks={commanderCard?.total_decks} price={commanderCard?.price} cardmarketURI={commanderCard?.cardmarket_uri}/>
              </div>
              <CardGroup className="scroll-mt-16" groupName={"Haute synergie"} Icon={undefined} id="highsynergy" cards={highSynergyList} />
              <CardGroup className="scroll-mt-16" groupName={"Planeswalker"} Icon={PlaneswalkerIcon} id="planeswalker" cards={planeswalkerList} />
              <CardGroup className="scroll-mt-16" groupName={"Créatures"} Icon={CreatureIcon} id="creature" cards={creatureList} />
              <CardGroup className="scroll-mt-16" groupName={"Rituels"} Icon={SorceryIcon} id="sorcery" cards={sorceryList} />
              <CardGroup className="scroll-mt-16" groupName={"Artefacts"} Icon={ArtifactIcon} id="artifact" cards={artifactList} />
              <CardGroup className="scroll-mt-16" groupName={"Éphémères"} Icon={InstantIcon} id="instant" cards={instantList} />
              <CardGroup className="scroll-mt-16" groupName={"Enchantements"} Icon={EnchantmentIcon} id="enchantment" cards={enchantmentList} />
              <CardGroup className="scroll-mt-16" groupName={"Terrains"} Icon={LandIcon} id="land" cards={landList} />
            </div>
          )}
        </div>
      </div>
      <div className="fixed top-80 ml-8 flex flex-col gap-2 text-stone-500">
        <a href="#highsynergy" className={`${scrollState == "highsynergy" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><PlaneswalkerIcon className={scrollState == "highsynergy" ? "h-5" : "h-4"} />Haute synergie</a>
        <a href="#planeswalker" className={`${scrollState == "planeswalker" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><PlaneswalkerIcon className={scrollState == "planeswalker" ? "h-5" : "h-4"} />Planeswalker</a>
        <a href="#creature" className={`${scrollState == "creature" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><CreatureIcon className={scrollState == "creature" ? "h-5" : "h-4"} />Créatures</a>
        <a href="#sorcery" className={`${scrollState == "sorcery" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><SorceryIcon className={scrollState == "sorcery" ? "h-5" : "h-4"} />Rituels</a>
        <a href="#artifact" className={`${scrollState == "artifact" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><ArtifactIcon className={scrollState == "artifact" ? "h-5" : "h-4"} />Artefacts</a>
        <a href="#instant" className={`${scrollState == "instant" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><InstantIcon className={scrollState == "instant" ? "h-5" : "h-4"} />Éphémères</a>
        <a href="#enchantment" className={`${scrollState == "enchantment" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><EnchantmentIcon className={scrollState == "enchantment" ? "h-5" : "h-4"} />Enchantements</a>
        <a href="#land" className={`${scrollState == "land" ? "text-black text-2xl" : "neutral-svg-filter"} flex flex-row items-center gap-1`}><LandIcon className={scrollState == "land" ? "h-5" : "h-4"} />Terrains</a>
      </div>
    </div>
  );
}
